@@ -1,11 +1,17 @@
+# -*- coding: utf-8 -*-
+
 import unittest
 import os
+
+from django.core.urlresolvers import reverse
+
 from .utils import StyleguideLoader, STYLEGUIDE_DIR_NAME
 
 
 CURRENT_PATH = os.path.dirname(__file__)
 PROJECT_ROOT = os.path.join(CURRENT_PATH, '..')
 MOCK_PROJECT_PATH = os.path.join(PROJECT_ROOT, 'styleguide_mock', 'templates')
+STYLEGUIDE_URL = reverse("styleguide.index")
 
 DOC_STRING = """@doc
 
@@ -44,7 +50,12 @@ class StyleguideLoaderTest(unittest.TestCase):
             ("0x-name.html", "0x-name"),
             ("89-name.html", "name"),
             ("name.nothing.html", "name.nothing"),
-            ("nothing.todo.no-where_to_go", "nothing.todo.no-where_to_go")
+            ("nothing.todo.no-where-to-go", "nothing.todo.no-where-to-go"),
+
+            # replacing underscore to whitespace
+            ("name_separated", "name separated"),
+            ("1_2_3_4_5_6", "1 2 3 4 5 6"),
+            ('____A', "    A"),
         ]
 
 
@@ -55,8 +66,8 @@ class StyleguideLoaderTest(unittest.TestCase):
 
     def test__get_components_from_folder(self):
         expected_result = [
-            { 'file_name': u'footer.html', 'name': u'footer', 'template': u'styleguide/layout/footer.html', 'doc': {} },
-            { 'file_name': u'header.html', 'name': u'header', 'template': u'styleguide/layout/header.html', 'doc': {} }
+            { 'file_name': u'footer.html', 'name': u'footer', 'template': u'styleguide/layout/footer.html', 'doc': {}, 'link': STYLEGUIDE_URL+'layout/footer' },
+            { 'file_name': u'header.html', 'name': u'header', 'template': u'styleguide/layout/header.html', 'doc': {}, 'link': STYLEGUIDE_URL+'layout/header' }
         ]
 
         path_to_test = os.path.join(MOCK_PROJECT_PATH, STYLEGUIDE_DIR_NAME)
