@@ -1,11 +1,18 @@
+# -*- coding: utf-8 -*-
+
 import os
 import re
 from collections import OrderedDict
+
+from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
+from django.core.urlresolvers import reverse
 from django.template import Lexer, Parser
 from django.template.defaulttags import CommentNode
 
-STYLEGUIDE_DIR_NAME = 'styleguide'
+
+STYLEGUIDE_DIR_NAME = getattr(settings, 'STYLEGUIDE_DIR_NAME', 'styleguide')
+
 FILE_NAME_RE = re.compile('^\d{2}\-')
 
 
@@ -18,7 +25,7 @@ class StyleguideLoader(object):
         -> tuple(string, string, ..)
         """
 
-        # Base on: https://github.com/django/django/blob/master/django/template/loaders/app_directories.py
+        # Based on: https://github.com/django/django/blob/master/django/template/loaders/app_directories.py
         styleguide_template_dirs = []
 
         try:
@@ -59,12 +66,12 @@ class StyleguideLoader(object):
 
         {
             'layout' : [
-                { 'name': 'header', 'file_name': 'header.html', 'template' : 'styleguide/layout/header.html' },
-                { 'name': 'footer', 'file_name': 'footer.html', 'template' : 'styleguide/layout/footer.html' },
+                { 'name': 'header', 'file_name': 'header.html', 'template' : 'styleguide/layout/header.html', ... },
+                { 'name': 'footer', 'file_name': 'footer.html', 'template' : 'styleguide/layout/footer.html', ... },
             ],
             'components' : [
-                'name': 'bar', 'file_name': 'bar.html', 'template' : 'styleguide/components/bar.html' },
-                'name': 'list', 'file_name': 'list.html', 'template' : 'styleguide/components/list.html' },
+                'name': 'bar', 'file_name': 'bar.html', 'template' : 'styleguide/components/bar.html', ... },
+                'name': 'list', 'file_name': 'list.html', 'template' : 'styleguide/components/list.html', ... },
             ]
         }
         """
@@ -101,11 +108,14 @@ class StyleguideLoader(object):
                     # only template files
                     continue
 
+                doc = self.get_doc_from_file(os.path.join(root, file_name))
+
                 component = {
-                    'name': self._format_file_name(file_name),
+                    'name': self._format_file_name(doc.get('name', file_name)),
                     'file_name': file_name,
                     'template': os.path.join(STYLEGUIDE_DIR_NAME, dir_name, file_name),
-                    'doc': self.get_doc_from_file(os.path.join(root, file_name))
+                    'doc': doc,
+                    'link': reverse("styleguide.component", args=(dir_name, file_name.replace('.html', ''),))
                 }
 
                 components.append(component)
@@ -120,7 +130,7 @@ class StyleguideLoader(object):
 
         # if the file_name startswith two digits, remove them
         file_name = FILE_NAME_RE.split(file_name)[-1]
-        return file_name.split('.html')[0]
+        return file_name.split('.html')[0].replace('_', ' ')
 
 
     def get_doc_from_file(self, file_path):
